Struct xcm_executor::Assets [−][src]
pub struct Assets {
pub fungible: BTreeMap<AssetId, u128>,
pub non_fungible: BTreeSet<(AssetId, AssetInstance)>,
}Expand description
List of non-wildcard fungible and non-fungible assets.
Fields
fungible: BTreeMap<AssetId, u128>The fungible assets.
non_fungible: BTreeSet<(AssetId, AssetInstance)>The non-fungible assets.
Implementations
A borrowing iterator over the fungible assets.
A borrowing iterator over the non-fungible assets.
A consuming iterator over all assets.
A borrowing iterator over all assets.
Mutate self to contain all given assets, saturating if necessary.
NOTE: Assets are always sorted, allowing us to optimize this function from O(n^2) to O(n).
Mutate self to contain the given asset, saturating if necessary.
Wildcard values of asset do nothing.
Swaps two mutable Assets, without deinitializing either one.
Alter any concretely identified assets by prepending the given MultiLocation.
WARNING: For now we consider this infallible and swallow any errors. It is thus the caller’s responsibility to ensure that any internal asset IDs are able to be prepended without overflow.
Returns an error unless all assets are contained in self. In the case of an error, the first asset in
assets which is not wholly in self is returned.
Mutates self to its original value less mask and returns true iff it contains at least mask.
Returns Ok with the non-wildcard equivalence of mask taken and mutates self to its value minus
mask if self contains asset, and return Err otherwise.
Mutates self to its original value less mask and returns true iff it contains at least mask.
Returns Ok with the non-wildcard equivalence of mask taken and mutates self to its value minus
mask if self contains asset, and return Err otherwise.
Mutates self to its original value less mask and returns true iff it contains at least mask.
Returns Ok with the non-wildcard equivalence of asset taken and mutates self to its value minus
asset if self contains asset, and return Err otherwise.
Consumes self and returns its original value excluding asset iff it contains at least asset.
Return the assets in self, but (asset-wise) of no greater value than mask.
Result is undefined if mask includes elements which match to the same asset more than once.
Example:
use xcm_executor::Assets;
use xcm::latest::prelude::*;
let assets_i_have: Assets = vec![ (Here, 100).into(), (vec![0], 100).into() ].into();
let assets_they_want: MultiAssetFilter = vec![ (Here, 200).into(), (vec![0], 50).into() ].into();
let assets_we_can_trade: Assets = assets_i_have.min(&assets_they_want);
assert_eq!(assets_we_can_trade.into_assets_iter().collect::<Vec<_>>(), vec![
(Here, 100).into(), (vec![0], 50).into(),
]);Trait Implementations
Performs the conversion.
Performs the conversion.
Performs the conversion.